#!/bin/bash
#------------------------------------------------------------------------------
# This is named: LazY Puppy SFS P.L.U.S. - (P)owerful (L)ive (U)ser (S)ystem
# It is the (r)evolutionary next step of the LazY Puppy Main SFS Handling
# Thanks for help and testings to: der-schutzhund, sunburnt, Bruce B and stu90
# Thanks to shinobar for introducing the --skip-fixmenus command in sfs_load
# This full featured RunScript version uses: lazy_sfs_load - modified by RSH (original by shinobar)
#------------------------------------------------------------------------------
# This RunScript was created with: SFS P.L.U.S. 3.9.9-8
# The first Version of SFS P.L.U.S. was released in: LazY Puppy 2.0.1
# Used OS: LazY Puppy - 300 - the smartest dog on the forum
# Full RunScript created as: LP2_MainFile.sfs.mainfile-sfs.run.sh, on: 2013-11-26
#------------------------------------------------------------------------------
# 2013-11-22 by Rainer Steffen Hain (RSH @ puppy-linux.org (murga forum))
#------------------------------------------------------------------------------

# Get Distro Data, build a temp DISTRO_SPECS if DISTRO_SPECS is not existing
DISTROSPECSMISSED="false"
if [ -f /etc/DISTRO_SPECS ]; then
	. /etc/DISTRO_SPECS
	else
	DISTROSPECSMISSED="true"
	if [ -f $APPDIR/.tools/build_temp_DISTRO_SPECS ]; then
		# For the use with Standalone RunScript directory
		$APPDIR/.tools/build_temp_DISTRO_SPECS
		else
		# For the use with installed RunScript directory
		/usr/sbin/ceelab/tools/build_temp_DISTRO_SPECS		
	fi
	. /etc/DISTRO_SPECS
fi
#DISTROSPECSMISSED="is_true"  # For testings only

# Get Application Directory
#--------------------------
APPDIR="`dirname $0`"
[ "$APPDIR" = "." ] && APPDIR="`pwd`"
export APPDIR="$APPDIR"
export APPDIR=`dirname $0`
[ $APPDIR = . ] && export APPDIR=`pwd`

# Get Directory of Language Files
if [ -d "$APPDIR/.locals" ]; then
	LOCALSDIR="$APPDIR/.locals" # Use locales from script directory
	APPDIRLOCALESOPT="true"
	else
	APPDIRLOCALESOPT="false"
	if [ -d /root/.my-sfs-scripts/.locals ]; then
		LOCALSDIR="/root/.my-sfs-scripts/.locals" # Use locales in /root/.my-sfs-scripts
		else # Use locales from upper directory
		LOCALSDIR1="`dirname "$0"`"
		LOCALSDIR2="`dirname "$LOCALSDIR1"`/.locals"
		LOCALSDIR="$LOCALSDIR2"
	fi
fi

# Get Language Settings
#----------------------
DEFLANG=`env|grep "LANG="`
LANGUAGE=`echo $LANG|head -c5`
TMPLANG="`ls $LOCALSDIR/ | grep $LANGUAGE`"
. $LOCALSDIR/en_US:english
[[ "$TMPLANG" != "en_US:english" ]] && . $LOCALSDIR/$TMPLANG 2> /dev/null
echo $TMPLANG
#------------------------------------------------------------------------------

# Remove redirected LazY Puppy Bootdirectory - if it is there
if [ -f /tmp/redirected_lp2bdl ]; then
	rm -f /tmp/redirected_lp2bdl
fi

# Is RunScript independent RoxApp Dir?
if [ "$APPDIRLOCALESOPT" = "true" ]; then
	CEELABPATH="$APPDIR/.tools"
	else
	CEELABPATH="/usr/sbin/ceelab/tools"
fi

# get LazY Puppy Bootdirectory
if [ ! -f /usr/sbin/ceelab/lp2_sys_data/LP2_BootDir ]; then
	$CEELABPATH/get_drive_list
	$CEELABPATH/get_boot_dir
	. /usr/sbin/ceelab/lp2_sys_data/LP2_BootDir
	else
	. /usr/sbin/ceelab/lp2_sys_data/LP2_BootDir
fi

# get pupmode
. /etc/rc.d/PUPSTATE

########################################
# Please, do not edit this here. Thanks!
########################################
DISPLAYAUTHOR="Rainer Steffen Hain (RSH, R-S-H (LazY Puppy) @ puppy-linux.org)"
DISPLAYDESKTOPFILE="mainfile-sfs.desktop"
DISPLAYEXE="main-script"
DISPLAYCMD="/usr/bin/main-script"
DISPLAYCHECKEXE="`basename "$0"`"
DISPLAYICON="`dirname "$0"`/.sfs-plus.png"
DISPLAYICONFORRUNSCRIPTMENU="sfs-plus.png"
DISPLAYDNLD="http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test"
DISPLAYMD5="b1f0c4ac8b258b58b06fb7a192225ab3"
DISPLAYMD5FILE="LP2_MainFile.sfs"
################################
# Editable Section of Parameters
################################
DISPLAYUSESFSLOAD="lazy_sfs_load"
if [ ! -f /usr/sbin/$DISPLAYUSESFSLOAD ]; then
	DISPLAYUSESFSLOAD="$CEELABPATH/lazy_sfs_load"
fi
DISPLAYFRSCRIPT="dummy"
DISPLAYDOFIXMENUS="true"
DISPLAYRPM5ONLY="false"
DISPLAYWINEISUSED="false"
DISPLAYAUTOUNLOADSFS="false"
DISPLAYDepList="LP2_DependentFile.sfs"
DISPLAYNDepList=""
DISPLAYRUNOVERRIDE="Module"
DISPLAYRUNOVERRIDELPBPLOPT="true"
DISPLAYRUNSCRIPTDEPENDENCIES=""
DISPLAYRUNOVERRIDEDEPSOPT="false"
DISPLAYUSEPIDOFCHECKOPT="false"
#################################################
# End of editable Section of Parameters
#################################################

# Is RunScript independent RoxApp Dir?
if [ "$APPDIRLOCALESOPT" = "true" ]; then
	CEELABPATH="$APPDIR/.tools"
	RUNLISTFILEDIR1="$APPDIR"
	RUNLISTFILEDIR2="$APPDIR"
	RUNLISTFILEDIR3="$APPDIR/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt"
	else
	CEELABPATH="/usr/sbin/ceelab/tools"
	RUNLISTFILEDIR1="`dirname "$0"`"
	RUNLISTFILEDIR2="`dirname "$RUNLISTFILEDIR1"`"
	RUNLISTFILEDIR3="$RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt"
fi
# Is RunScript marked as NOT_TO_RUN for the currently running OS?
if (grep "$DISPLAYCHECKEXE" $RUNLISTFILEDIR3) then
	echo "This RunScript is marked as in-executable for LazY Puppy! Can not execute $DISPLAYEXE!"
	Xdialog --title "$DISPLAYMD5FILE - $DISPLAYEXE" --icon "$DISPLAYICON" --timeout 5 --no-buttons  --msgbox "$SFSMARKEDASINEXECMSG" 0 0
	exit 0
fi

# Avoid RunScript calling itself
if [ "`basename $DISPLAYEXE`" = "$DISPLAYCHECKEXE" ]; then
	echo "This RunScript is calling itself! Can not execute $DISPLAYEXE!"
	Xdialog --title "$DISPLAYMD5FILE - $DISPLAYEXE" --icon "$DISPLAYICON" --timeout 5 --no-buttons  --msgbox "$SFSCALLSITSELFMSG1 `basename $DISPLAYCMD`, $SFSCALLSITSELFMSG2 `dirname $DISPLAYCMD`, $SFSCALLSITSELFMSG3 $DISPLAYMD5FILE $SFSCALLSITSELFMSG4 $DISPLAYMD5FILE, $SFSCALLSITSELFMSG5" 0 0
	exit 0
fi

# Disable dependencies check for all SFS files
if [ "$DISPLAYRUNOVERRIDEDEPSOPT" = "true" ]; then
	/root/my-roxapps/SFS-ASCRIPT/disable_check_all_sfs_deps
fi

# Create file with dependencies defined in RunScript
if [ "$DISPLAYRUNSCRIPTDEPENDENCIES" != "" ]; then
	echo $DISPLAYRUNSCRIPTDEPENDENCIES > /tmp/$DISPLAYMD5FILE.dependencies
fi

# Override LazY Puppy boot directory to load SFS files
if [ "$DISPLAYRUNOVERRIDE" = "" ]; then
	DISPLAYRUNOVERRIDE="false"
fi
#if [ "$DISPLAYRUNOVERRIDE" != "false" ]; then
#	LP2BDL=/mnt/$DISPLAYRUNOVERRIDE
#fi
if [ "$DISPLAYRUNOVERRIDELPBPLOPT" = "true" ]; then
	LP2BDL=$LP2BPL/$DISPLAYRUNOVERRIDE
	echo "$LP2BDL" > /tmp/redirected_lp2bdl # redirected LazY Puppy Bootdirectory
	if [ ! -d $LP2BDL ]; then
		$CEELABPATH/mnt_my_bootdrive &
		sleep 2
	fi
fi

#PMEDIA="cd"
# Override LazY Puppy boot directory to load SFS files
# Second part, this is for running from CD/DVD and to download SFS Modules
# to a different locations, since one can not donwload to CD/DVD
if [[ "$PMEDIA" = "cd" || "$PMEDIA" = "CD" || "$PMEDIA" = "dvd" || "$PMEDIA" = "DVD" ]]; then
	MODDIRECTORY="Modules_"$DISTRO_FILE_PREFIX"_Temp"
	MODPARTITION="/tmp/$MODDIRECTORY"
	LP2BDL="$MODPARTITION"	
	if [ ! -f /tmp/download_dir_temp ]; then
		read DNLDPARTCHECK < $RUNLISTFILEDIR2/.data/download_dir_temp
		if [ "$DNLDPARTCHECK" = "" ]; then
			$RUNLISTFILEDIR2/set_download_dir
		fi
	fi
	if [ -f $RUNLISTFILEDIR2/.data/download_dir_temp ]; then
		if [ ! -f /tmp/download_dir_temp ]; then
			cp -af $RUNLISTFILEDIR2/.data/download_dir_temp /tmp/
		fi
		read DNLDPART < /tmp/download_dir_temp
		if [ "$DNLDPART" != "" ]; then
			LP2BDL="/mnt/$DNLDPART/$MODDIRECTORY"
			$CEELABPATH/mnt_drive $DNLDPART
			mkdir -p $LP2BDL
		fi
	fi
	echo "$LP2BDL" > /tmp/redirected_lp2bdl # redirected LazY Puppy Bootdirectory
	DISPLAYUSESFSLOAD="$CEELABPATH/lazy_sfs_load_cd"
fi

# list of already loaded sfs files
. /etc/rc.d/BOOTCONFIG
echo "$LASTUNIONRECORD" > /tmp/xsfslist_tmp
sfslistfile=/tmp/xsfslist_tmp
downloadfail="false"

if [ "$DISPLAYRPM5ONLY" = "true" ]; then
	if [ "$PUPMODE" != "5" ]; then
		Xdialog --title "$DISPLAYEXE" --timeout 5 --icon "/usr/share/pixmaps/squashfs-image.png" --msgbox "LP2_MainFile.sfs $RSCRPM5ONLYMSG" 0 0
		exit 0 #111
	fi
fi

# check fo nogo dependencies
if [ "$APPDIRLOCALESOPT" = "true" ]; then
	# Do not se RunScripts directory name to get the NOGO list
	if [ -f $RUNLISTFILEDIR2/.nogo_list ]; then
		for nogo_file in `cat $RUNLISTFILEDIR2/.nogo_list`;
		do
			if (grep "$nogo_file" /tmp/xsfslist_tmp) then
				Xdialog --title "$DISPLAYMD5FILE" --icon "/usr/share/pixmaps/squashfs-image.png" --timeout 15 --ok-label "$YESBTNTXT" --cancel-label "$NOBTNTXT" --yesno "\n $DISPLAYMD5FILE $CANTLOAD1 \n\n $CANTLOAD2 $nogo_file \n\n $DOUNLOADTXT1 $nogo_file $DOUNLOADTXT2\n" 0 0
				if [ "$?" = "0" ]; then
					$DISPLAYUSESFSLOAD --unload --cli --skip-fixmenus --quiet "$LP2BDL/$nogo_file"
					else
					exit 0 #112
				fi
			fi
		done
	fi
	else # Use RunScripts directory name to get the NOGO list
	if [ -f $RUNLISTFILEDIR2/LP2_MainFile.sfs.Scripts/.nogo_list ]; then
		for nogo_file in `cat $RUNLISTFILEDIR2/LP2_MainFile.sfs.Scripts/.nogo_list`;
		do
			if (grep "$nogo_file" /tmp/xsfslist_tmp) then
				Xdialog --title "$DISPLAYMD5FILE" --icon "/usr/share/pixmaps/squashfs-image.png" --timeout 15 --ok-label "$YESBTNTXT" --cancel-label "$NOBTNTXT" --yesno "$DISPLAYMD5FILE $CANTLOAD1\n\n$CANTLOAD2 $nogo_file\n\n$DOUNLOADTXT1 $nogo_file $DOUNLOADTXT2\n" 0 0
				if [ "$?" = "0" ]; then
					$DISPLAYUSESFSLOAD --unload --cli --skip-fixmenus --quiet "$LP2BDL/$nogo_file"
					else
					exit 0 #112
				fi
			fi
		done
	fi
fi

# check for file name as parameter - if, can run the script with file to load
if [ "$1" != "" ]; then
	param1="$1"
	else
	param1=""
fi

# first check the NoGo-Dependencies
check_all_sfs_nogo_deps

# run a script at first (set some parameters, run programs needed etc.)
# is a user defined script - does nothing if it is empty or a "dummy"
if [ "$DISPLAYFRSCRIPT" != "" ]; then
	if [ "$DISPLAYFRSCRIPT" != "dummy" ]; then
		if [ -f "$DISPLAYFRSCRIPT" ]; then
			exec $DISPLAYFRSCRIPT &
			# just wait to let the user act (start qjackctl f.e)
			sleep 5
		fi
	fi
fi

if [ "$APPDIRLOCALESOPT" = "true" ]; then
	. $RUNLISTFILEDIR2/.md5sum/LP2_MainFile.sfs.md5sum.txt
	else
	. $RUNLISTFILEDIR2/LP2_MainFile.sfs.Scripts/.md5sum/LP2_MainFile.sfs.md5sum.txt
fi
if [ "$MYMD5SUM" != "" ]; then
	DISPLAYMD5=$MYMD5SUM
fi

# Check for Application
#----------------------
sfsmustload="false"

# if Program found
if [ "$(which /usr/bin/main-script)" ]; then
	
	# first check the RunScript dependencies of LP2_MainFile.sfs
	if [ "$DISPLAYRUNSCRIPTDEPENDENCIES" != "" ]; then
		for ideps in `cat /tmp/$DISPLAYMD5FILE.dependencies`;
		do
			if [ "$ideps" != "" ]; then
				sfsisload="false"
				for i in `cat $sfslistfile`;
				do
					sfsresult=`echo $i | grep $ideps`
					if [ "$sfsresult" != "" ]; then
						# sfs is loaded
						sfsisload="true"
					fi
				done
				if [ "$DISPLAYDNLD" != "Download-Link" ]; then
					if [ ! -f $LP2BDL/$ideps ]; then
						# download the dependent file from the web - new version (LP203)
						$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
						sync
					fi
				fi
				# sfs is not loaded
				if [ "$sfsisload" = "false" ]; then
					sfsmustload="true"
					$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
				fi
			fi
		done
	fi
	
	# second check SFS inside dependencies of LP2_MainFile.sfs
	if [ "$DISPLAYRUNOVERRIDEDEPSOPT" = "false" ]; then
		if [ -f /.LazYPuppySFSData/SFSDependencies/LP2_MainFile.sfs.dependencies ]; then
		
			for ideps in `cat /.LazYPuppySFSData/SFSDependencies/LP2_MainFile.sfs.dependencies`;
			do
				if [ "$ideps" != "" ]; then
					sfsisload="false"
					for i in `cat $sfslistfile`;
					do
						sfsresult=`echo $i | grep $ideps`
						if [ "$sfsresult" != "" ]; then
							# sfs is loaded
							sfsisload="true"
						fi
					done
					if [ "$DISPLAYDNLD" != "Download-Link" ]; then
						if [ ! -f $LP2BDL/$ideps ]; then
							# download the dependent file from the web - new version (LP203)
							$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
							sync
						fi
					fi
					# sfs is not loaded
					if [ "$sfsisload" = "false" ]; then
						sfsmustload="true"
						$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
					fi
				fi
			done
			
		fi # end check dependencies of LP2_MainFile.sfs
	fi # if do not override internal deps
	
	if [ "$param1" != "" ]; then
		# program available, run the program /usr/bin/main-script
		/usr/bin/main-script "$param1" &
		else
		# program available, run the program /usr/bin/main-script
		/usr/bin/main-script &
	fi
	
	#sleep 1 # just show info gui a little longer
	#kill $X3PID # kill information GUI
	
	# check and load all needed dependencies of all sfs files
	if [[ "$PMEDIA" = "cd" || "$PMEDIA" = "CD" || "$PMEDIA" = "dvd" || "$PMEDIA" = "DVD" ]]; then
		echo "Do not execute: check_all_sfs_deps"
		else
		check_all_sfs_deps
	fi
	# run apps listed inside sfs # still not available
	run_all_sfs_autoprogs "/usr/bin/main-script"
	
	# new dependency loaded - needs to rebuild the menus
	if [ "$sfsmustload" = "true" ]; then
		fixmenus &
	fi
		
	#-------------------------------------------------------#
	else # if [ "$(which /usr/bin/main-script)" ]; # Program not found
	#-------------------------------------------------------#
	
	#kill $X3PID
	Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --no-buttons --ignore-eof --infobox "\n $SFSTOLOADMSG1 LP2_MainFile.sfs\n $SFSTOLOADMSG2 $DISPLAYEXE $SFSTOLOADMSG3\n $SFSTOLOADMSG4\n\n $DEPLISTTTL\n $DISPLAYDepList\n\n $NDEPLISTTTL\n $DISPLAYNDepList\n\n $SFSTOLOADMSG5\n" 0 0 0 &
	X3PID=$!
	
	$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/LP2_MainFile.sfs"
	
	# first check the RunScript dependencies of LP2_MainFile.sfs
	if [ "$DISPLAYRUNSCRIPTDEPENDENCIES" != "" ]; then
		for ideps in `cat /tmp/$DISPLAYMD5FILE.dependencies`;
		do
			if [ "$ideps" != "" ]; then
				sfsisload="false"
				for i in `cat $sfslistfile`;
				do
					sfsresult=`echo $i | grep $ideps`
					if [ "$sfsresult" != "" ]; then
						# sfs is loaded
						sfsisload="true"
					fi
				done
				if [ "$DISPLAYDNLD" != "Download-Link" ]; then
					if [ ! -f $LP2BDL/$ideps ]; then
						# download the dependent file from the web - new version (LP203)
						$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
						sync
					fi
				fi
				# sfs is not loaded
				if [ "$sfsisload" = "false" ]; then
					sfsmustload="true"
					$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
				fi
			fi
		done
	fi
	
	# second check SFS inside dependencies of LP2_MainFile.sfs
	if [ "$DISPLAYRUNOVERRIDEDEPSOPT" = "false" ]; then
		if [ -f /.LazYPuppySFSData/SFSDependencies/LP2_MainFile.sfs.dependencies ]; then
		
			for ideps in `cat /.LazYPuppySFSData/SFSDependencies/LP2_MainFile.sfs.dependencies`;
			do
				if [ "$ideps" != "" ]; then
					sfsisload="false"
					for i in `cat $sfslistfile`;
					do
						sfsresult=`echo $i | grep $ideps`
						if [ "$sfsresult" != "" ]; then
							# sfs is loaded
							sfsisload="true"
						fi
					done
					if [ "$DISPLAYDNLD" != "Download-Link" ]; then
						if [ ! -f $LP2BDL/$ideps ]; then
							# download the dependent file from the web - new version (LP203)
							$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
							sync
						fi
					fi
					# sfs is not loaded
					if [ "$sfsisload" = "false" ]; then
						$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
					fi
				fi
			done
			
		fi # end check dependencies of LP2_MainFile.sfs
	fi # if do not override internal deps
	
	# if script is made for wine, run this
	if [ "$DISPLAYWINEISUSED" = "true" ]; then
		cd /root/.wine
		wine regedit registry.ok
	fi
	
	# program available now?
	# if Program found
	if [ "$(which /usr/bin/main-script)" ]; then

		kill $X3PID # kill information GUI of loading the SFS
		if [ "$param1" != "" ]; then
			# program available, run the program /usr/bin/main-script
			/usr/bin/main-script "$param1" &
			else
			# program available, run the program /usr/bin/main-script
			/usr/bin/main-script &
		fi
	
		#-------------------------------------------------------------------#
		else # if [ "$(which /usr/bin/main-script)" ]; sfs not available ---> download
		#-------------------------------------------------------------------#
	
		sfsmustload="true"
		
		kill $X3PID # kill information GUI of loading the SFS
		Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --timeout 60 --ok-label "$SFSDNLDBTN" --cancel-label "$SFSNOTDNLDBTN" --yesno "\nLP2_MainFile.sfs $SFSMISSEDMSG1" 0 0
		
		case $? in
			0) ;;
			1) rm /tmp/xsfslist_tmp
				exit 0 ;; #1
			255) rm /tmp/xsfslist_tmp
				exit 0 ;; #1
		esac
		
		if [ "$DISPLAYDNLD" != "Download-Link" ]; then
			Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --no-buttons --ignore-eof --infobox "\n $SFSDOWNLOADMSG1 LP2_MainFile.sfs $SFSDOWNLOADMSG2 $DISPLAYEXE $SFSDOWNLOADMSG3\n" 0 0 0 &
			X3PID=$!
			
			# download the file from the web - new version (LP203)
			$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/LP2_MainFile.sfs"
			sync
			
			sleep 1
			MD5SM=$(md5sum $LP2BDL/LP2_MainFile.sfs)
			for md5 in $MD5SM; do
				md5bn=`basename $md5`
				if [ "$md5bn" != "LP2_MainFile.sfs" ]; then
					MD5SM=$md5bn
					break
				fi
			done
			
			# write download log file --> Name of sfs, md5sum-is, md5sum-dl
			#rm /tmp/lp2sfsdl_md5sum_check_log.txt
			echo "LP2_MainFile.sfs" SFS-File >> /tmp/lp2sfsdl_md5sum_check_log.txt
			echo "$MD5SM" downloaded file >> /tmp/lp2sfsdl_md5sum_check_log.txt
			echo "$DISPLAYMD5" RunScript entry >> /tmp/lp2sfsdl_md5sum_check_log.txt
			echo "" >> /tmp/lp2sfsdl_md5sum_check_log.txt
			
			# Maybe remove later ? ? ?
			if [ "$MD5SM" != "$DISPLAYMD5" ]; then
				kill $X3PID # kill information GUI
				Xdialog --title "LP2_MainFile.sfs" --icon "$DISPLAYICON" --timeout 10 --msgbox "$SFSMD5WRONGMSG" 0 0
				rm /tmp/xsfslist_tmp
				#rm $LP2BDL/LP2_MainFile.sfs # remove downloaded file - disabled
				#exit 0 # disabled 2013-06-18 RSH --> try to execute though!!!
			fi
			
			kill $X3PID # Download Info GUI
			Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --no-buttons --ignore-eof --infobox "\n $SFSTOLOADMSG1 LP2_MainFile.sfs\n $SFSTOLOADMSG2 $DISPLAYEXE $SFSTOLOADMSG3\n $SFSTOLOADMSG4\n\n $DEPLISTTTL\n $DISPLAYDepList\n\n $NDEPLISTTTL\n $DISPLAYNDepList\n\n $SFSTOLOADMSG5\n" 0 0 0 &
			X3PID=$!
			
			# load the sfs
			$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/LP2_MainFile.sfs"
			
			# first check the RunScript dependencies of LP2_MainFile.sfs
			if [ "$DISPLAYRUNSCRIPTDEPENDENCIES" != "" ]; then
				for ideps in `cat /tmp/$DISPLAYMD5FILE.dependencies`;
				do
					if [ "$ideps" != "" ]; then
						sfsisload="false"
						for i in `cat $sfslistfile`;
						do
							sfsresult=`echo $i | grep $ideps`
							if [ "$sfsresult" != "" ]; then
								# sfs is loaded
								sfsisload="true"
							fi
						done
						if [ "$DISPLAYDNLD" != "Download-Link" ]; then
							if [ ! -f $LP2BDL/$ideps ]; then
								# download the dependent file from the web - new version (LP203)
								$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
								sync
							fi
						fi
						# sfs is not loaded
						if [ "$sfsisload" = "false" ]; then
							sfsmustload="true"
							$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
						fi
					fi
				done
			fi
			
			# second check SFS inside dependencies of LP2_MainFile.sfs
			for ideps in `cat /.LazYPuppySFSData/SFSDependencies/LP2_MainFile.sfs.dependencies`;
			do
				if [ "$ideps" != "" ]; then
					sfsisload="false"
					for i in `cat $sfslistfile`;
					do
						sfsresult=`echo $i | grep $ideps`
						if [ "$sfsresult" != "" ]; then
							# sfs is loaded
							sfsisload="true"
						fi
					done
					if [ "$DISPLAYDNLD" != "Download-Link" ]; then
						if [ ! -f $LP2BDL/$ideps ]; then
							# download the dependent file from the web - new version (LP203)
							$CEELABPATH/lazy_download_file "http://smokey01.com/RSH/Modularity-Packages/SFS-PLUS-Download-Test/$ideps"
							sync
						fi
					fi
					# sfs is not loaded
					if [ "$sfsisload" = "false" ]; then
						sfsmustload="true"
						$DISPLAYUSESFSLOAD --cli --skip-fixmenus --quiet "$LP2BDL/$ideps"
					fi
				fi
			done
			
			# if script is made for wine, run this
			if [ "$DISPLAYWINEISUSED" = "true" ]; then
				cd /root/.wine
				wine regedit registry.ok
			fi
			
			# program available now?
			# if Program found
			if [ "$(which /usr/bin/main-script)" ]; then
				kill $X3PID # kill information GUI
				if [ "$param1" != "" ]; then
					# program available, run the program /usr/bin/main-script
					/usr/bin/main-script "$param1" &
					else
					# program available, run the program /usr/bin/main-script
					/usr/bin/main-script &
				fi
				
				else
				
				kill $X3PID # kill information GUI
				Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --no-buttons --ignore-eof --infobox "\n $SFSDOWNLOADFAILMSG1 LP2_MainFile.sfs $SFSDOWNLOADFAILMSG2\n" 0 0 0 &
				X3PID=$!
				rm /tmp/xsfslist_tmp
				sleep 3 # just show info gui a little longer
				kill $X3PID # kill information GUI
				exit 0 #1
			fi
						
			else
			
			#kill $X3PID # kill information GUI
			Xdialog --title "LP2_MainFile.sfs - $DISPLAYEXE" --icon "$DISPLAYICON" --no-buttons --ignore-eof --infobox "\n $SFSDOWNLOADFAILMSG1 LP2_MainFile.sfs $SFSDOWNLOADFAILMSG2\n" 0 0 0 &
			X3PID=$!
			rm /tmp/xsfslist_tmp
			sleep 3 # just show info gui a little longer
			kill $X3PID # kill information GUI
			exit 0 #1
		fi
		
	fi
	
	# check and load all needed dependencies of all sfs files
	if [[ "$PMEDIA" = "cd" || "$PMEDIA" = "CD" || "$PMEDIA" = "dvd" || "$PMEDIA" = "DVD" ]]; then
		echo "Do not execute: check_all_sfs_deps"
		else
		check_all_sfs_deps
	fi
	# run apps listed inside sfs
	run_all_sfs_autoprogs "/usr/bin/main-script"
	
	# if menu entry is not added at making the RunScript do fixmenus
	if [ "$DISPLAYDOFIXMENUS" = "true" ]; then
		fixmenus &
	fi
	
	# Create and execute AutoUnload Script ---> runs in background
	if [ "$DISPLAYAUTOUNLOADSFS" = "true" ]; then
		autounload-sfs "$LP2BDL/LP2_MainFile.sfs" "/usr/bin/main-script" &
		sleep .1
		/tmp/LP2_MainFile.sfs.AutoUnload.sh &
	fi
	
fi

rm /tmp/xsfslist_tmp

# Remove redirected LazY Puppy Bootdirectory - if it is there
if [ -f /tmp/redirected_lp2bdl ]; then
	rm -f /tmp/redirected_lp2bdl
fi

# Write to Log File related to the running OS and do use this function to
# check PID of application to run
if [ "$DISPLAYUSEPIDOFCHECKOPT" = "true" ]; then
	sleep 5 # Just wait for the Application to be executed completely
	if (grep "$DISPLAYCHECKEXE" $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt) then
		echo "$DISPLAYCHECKEXE" >/dev/null
		else
		if [ "`pidof "$DISPLAYEXE"`" != "" ]; then
			#echo "`pidof "$DISPLAYEXE"`" > /tmp/.PID_CHECKED_FOR_BATCH_SFSPLUS_RUNSCRIPT_TESTER
			if (grep "$DISPLAYCHECKEXE" $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt) then
				echo "$DISPLAYCHECKEXE" >/dev/null
				else
				echo "$DISPLAYCHECKEXE" >> $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt
				sort -u $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt > /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt_sorted_list
				mv /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt_sorted_list $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt
			fi
			else
			APPISASCRIPT="false"
			read FIRSTLINE < $DISPLAYCMD
			if [ "$FIRSTLINE" = "" ]; then
				APPISASCRIPT="true"
				elif [[ "$FIRSTLINE" == *!/bin/bash* ]]; then
				APPISASCRIPT="true"
				elif [[ "$FIRSTLINE" == *!/bin/sh* ]]; then
				APPISASCRIPT="true"
				elif [[ "$FIRSTLINE" == *java* ]]; then
				APPISASCRIPT="true"
				elif [[ "$FIRSTLINE" == *-jar* ]]; then
				APPISASCRIPT="true"
				elif [[ "$FIRSTLINE" == *!/usr/bin/env* ]]; then
				APPISASCRIPT="true"
			fi
			if [ "$APPISASCRIPT" = "true" ]; then
				Xdialog --title "$DISPLAYCHECKEXE" --icon "$DISPLAYICON" --ok-label "$YESBTNTXT" --cancel-label "$NOBTNTXT" --yesno "$APPISASCRIPTMSG1 $DISPLAYCHECKEXE, $APPISASCRIPTMSG2" 0 0
				if [ "$?" = "0" ]; then
					echo "$DISPLAYCHECKEXE" >> $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt
					sort -u $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt > /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt_sorted_list
					mv /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt_sorted_list $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_yes.txt
					else
					echo "$DISPLAYCHECKEXE" >> $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt
					sort -u $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt > /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt_sorted_list
					mv /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt_sorted_list $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt
					$DISPLAYUSESFSLOAD --unload --cli --skip-fixmenus --quiet "$LP2BDL/LP2_MainFile.sfs"
				fi
				else
				if (grep "$DISPLAYCHECKEXE" $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt) then
					echo "$DISPLAYCHECKEXE" >/dev/null
					else
					echo "$DISPLAYCHECKEXE" >> $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt
					sort -u $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt > /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt_sorted_list
					mv /tmp/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt_sorted_list $RUNLISTFILEDIR2/.data/$DISTRO_FILE_PREFIX"_"$DISTRO_VERSION.runlist_no.txt
					$DISPLAYUSESFSLOAD --unload --cli --skip-fixmenus --quiet "$LP2BDL/LP2_MainFile.sfs"
				fi
			fi
		fi
	fi
fi

exit 0
#------------------------------------------------------------------------------
# End of LP2_MainFile.sfs.mainfile-sfs.run.sh Script
#------------------------------------------------------------------------------
# Me, Rainer Steffen Hain, did start programming in bash (shellscript) at
# 05. September 2011. I could not imagine the day I would write a program
# that generates full working RunScripts of programs inside unmounted or
# unloaded sfs files (like this one). It was a lot of hard work, but also
# a lot of FUN. I did really like that.
#------------------------------------------------------------------------------
# This RunScript was created with: SFS P.L.U.S. 3.9.9-8
#------------------------------------------------------------------------------
# Date: 2013-11-26
#-----------------
